==> haskell-hedgehog-0.6.1-39-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hedgehog
version: 0.6.1
id: hedgehog-0.6.1-IekKPhsOloa6SGKw7SdctR
key: hedgehog-0.6.1-IekKPhsOloa6SGKw7SdctR
license: BSD-3-Clause
maintainer: Jacob Stanley <jacob@stanley.io>
author: Jacob Stanley
homepage: https://hedgehog.qa
synopsis: Hedgehog will eat all your bugs.
description:
    Hedgehog is a modern property-based testing system, in the spirit of
    QuickCheck. Hedgehog uses integrated shrinking, so shrinks obey the
    invariants of generated values by construction.
    .
    To get started quickly, see the examples:
    <https://github.com/hedgehogqa/haskell-hedgehog/tree/master/hedgehog-example>
category: Testing
abi: c794a2a9045073da85b16d19295270cd
exposed: True
exposed-modules:
    Hedgehog Hedgehog.Gen Hedgehog.Internal.Config
    Hedgehog.Internal.Discovery Hedgehog.Internal.Distributive
    Hedgehog.Internal.Exception Hedgehog.Internal.Gen
    Hedgehog.Internal.HTraversable Hedgehog.Internal.Opaque
    Hedgehog.Internal.Property Hedgehog.Internal.Queue
    Hedgehog.Internal.Range Hedgehog.Internal.Region
    Hedgehog.Internal.Report Hedgehog.Internal.Runner
    Hedgehog.Internal.Seed Hedgehog.Internal.Show
    Hedgehog.Internal.Shrink Hedgehog.Internal.Source
    Hedgehog.Internal.State Hedgehog.Internal.TH Hedgehog.Internal.Tree
    Hedgehog.Internal.Tripping Hedgehog.Range
import-dirs: /usr/lib/ghc-8.6.5/site-local/hedgehog-0.6.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hedgehog-0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hedgehog-0.6.1
hs-libraries: HShedgehog-0.6.1-IekKPhsOloa6SGKw7SdctR
depends:
    ansi-terminal-0.9.1-4EGEPOXIA9UHNrgfDydiTP
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG base-4.12.0.0
    bytestring-0.10.8.2
    concurrent-output-1.10.10-C4C3DoCxLW0Aq9BdLCwXti containers-0.6.0.1
    directory-1.3.3.0 exceptions-0.10.2-Gj8cIuYcXhQEAym4RMvM4g
    lifted-async-0.10.0.4-J6uS5uOdkRY2igyti8hFvz
    mmorph-1.1.3-FfwptCv2VaAjI2vq7vsWW
    monad-control-1.0.2.3-EKrTS47Oi8IKd1pTyskzd3 mtl-2.2.2
    pretty-show-1.9.5-4s9IVBWSe01IF3L4DDRCg8
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    resourcet-1.2.2-BD7KiCA7p3Q4m6RD0qps5k stm-2.5.0.0
    template-haskell-2.14.0.0 text-1.2.3.1
    th-lift-0.7.11-hZJVZ2zmXw59mRAYP9RXW time-1.8.0.2
    transformers-0.5.6.2
    transformers-base-0.4.5.2-KWttVZ7nb0vsLFTQBq79t unix-2.7.2.2
    wl-pprint-annotated-0.1.0.1-HJehfQsAINoDb4o9GbdZCF
haddock-interfaces: /usr/share/doc/haskell-hedgehog/html/hedgehog.haddock
haddock-html: /usr/share/doc/haskell-hedgehog/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hedgehog-0.6.1-40-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hedgehog
version: 0.6.1
id: hedgehog-0.6.1-LUecUyASaXoST2AOxX6sB
key: hedgehog-0.6.1-LUecUyASaXoST2AOxX6sB
license: BSD-3-Clause
maintainer: Jacob Stanley <jacob@stanley.io>
author: Jacob Stanley
homepage: https://hedgehog.qa
synopsis: Hedgehog will eat all your bugs.
description:
    Hedgehog is a modern property-based testing system, in the spirit of
    QuickCheck. Hedgehog uses integrated shrinking, so shrinks obey the
    invariants of generated values by construction.
    .
    To get started quickly, see the examples:
    <https://github.com/hedgehogqa/haskell-hedgehog/tree/master/hedgehog-example>
category: Testing
abi: da0970b7cac22389cb70ed2f32e931e0
exposed: True
exposed-modules:
    Hedgehog Hedgehog.Gen Hedgehog.Internal.Config
    Hedgehog.Internal.Discovery Hedgehog.Internal.Distributive
    Hedgehog.Internal.Exception Hedgehog.Internal.Gen
    Hedgehog.Internal.HTraversable Hedgehog.Internal.Opaque
    Hedgehog.Internal.Property Hedgehog.Internal.Queue
    Hedgehog.Internal.Range Hedgehog.Internal.Region
    Hedgehog.Internal.Report Hedgehog.Internal.Runner
    Hedgehog.Internal.Seed Hedgehog.Internal.Show
    Hedgehog.Internal.Shrink Hedgehog.Internal.Source
    Hedgehog.Internal.State Hedgehog.Internal.TH Hedgehog.Internal.Tree
    Hedgehog.Internal.Tripping Hedgehog.Range
import-dirs: /usr/lib/ghc-8.6.5/site-local/hedgehog-0.6.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hedgehog-0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hedgehog-0.6.1
hs-libraries: HShedgehog-0.6.1-LUecUyASaXoST2AOxX6sB
depends:
    ansi-terminal-0.9.1-JvtMBmSUh1eHKvsAMwthXj
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG base-4.12.0.0
    bytestring-0.10.8.2
    concurrent-output-1.10.10-96EdlFSmy2kBNWLEbCc5hK containers-0.6.0.1
    directory-1.3.3.0 exceptions-0.10.2-5svhVYbSwFFKlwgRdeEWGk
    lifted-async-0.10.0.4-DqwhW4ERcP49efLffE84IC
    mmorph-1.1.3-FfwptCv2VaAjI2vq7vsWW
    monad-control-1.0.2.3-EKrTS47Oi8IKd1pTyskzd3 mtl-2.2.2
    pretty-show-1.9.5-4s9IVBWSe01IF3L4DDRCg8
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    resourcet-1.2.2-GrOWSwxHGOj1LZp32tMtSY stm-2.5.0.0
    template-haskell-2.14.0.0 text-1.2.3.1
    th-lift-0.7.11-hZJVZ2zmXw59mRAYP9RXW time-1.8.0.2
    transformers-0.5.6.2
    transformers-base-0.4.5.2-KWttVZ7nb0vsLFTQBq79t unix-2.7.2.2
    wl-pprint-annotated-0.1.0.1-J7ygJRVPU2aBM18KpCjX7Q
haddock-interfaces: /usr/share/doc/haskell-hedgehog/html/hedgehog.haddock
haddock-html: /usr/share/doc/haskell-hedgehog/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
